@@ -1,3 +1,18 @@
+# Copyright Contributors to the Rez project
+#
+# Licensed under the Apache License, Version 2.0 (the "License");
+# you may not use this file except in compliance with the License.
+# You may obtain a copy of the License at
+#
+#     http://www.apache.org/licenses/LICENSE-2.0
+#
+# Unless required by applicable law or agreed to in writing, software
+# distributed under the License is distributed on an "AS IS" BASIS,
+# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+# See the License for the specific language governing permissions and
+# limitations under the License.
+
+
 """
 Utilities related to formatting output or translating input.
 """
@@ -15,7 +30,7 @@ import re
 import time
 
 
-PACKAGE_NAME_REGSTR = "[a-zA-Z_0-9](\.?[a-zA-Z0-9_]+)*"
+PACKAGE_NAME_REGSTR = r"[a-zA-Z_0-9](\.?[a-zA-Z0-9_]+)*"
 PACKAGE_NAME_REGEX = re.compile(r"^%s\Z" % PACKAGE_NAME_REGSTR)
 
 ENV_VAR_REGSTR = r'\$(\w+|\{[^}]*\})'
@@ -43,8 +58,8 @@ def is_valid_package_name(name, raise_error=False):
         bool.
     """
     is_valid = (
-        PACKAGE_NAME_REGEX.match(name) and
-        name not in invalid_package_names
+        PACKAGE_NAME_REGEX.match(name)
+        and name not in invalid_package_names
     )
 
     if raise_error and not is_valid:
@@ -132,7 +147,7 @@ class ObjectStringFormatter(Formatter):
         try:
             return Formatter.get_field(self, field_name, args, kwargs)
         except (AttributeError, KeyError, TypeError):
-            reg = re.compile("[^\.\[]+")
+            reg = re.compile(r"[^\.\[]+")
             try:
                 key = reg.match(field_name).group()
             except:
@@ -459,8 +474,10 @@ def positional_number_string(n):
 # regex used to expand user; set here to avoid recompile on every call
 EXPANDUSER_RE = re.compile(
     r'(\A|\s|[{pathseps}])~([{seps}]|[{pathseps}]|\s|\Z)'.format(
-    seps = re.escape(''.join(set([os.sep + (getattr(os, 'altsep') or os.sep)]))),
-    pathseps = re.escape(''.join(set([os.pathsep + ';'])))))
+        seps=re.escape(''.join(set([os.sep + (getattr(os, 'altsep') or os.sep)]))),
+        pathseps=re.escape(''.join(set([os.pathsep + ';'])))
+    )
+)
 
 
 def expanduser(path):
@@ -537,19 +554,3 @@ def minor_header_comment(executor, txt):
     executor.comment("")
     executor.comment(txt)
     executor.comment(_header_br_minor)
-
-
-# Copyright 2013-2016 Allan Johns.
-#
-# This library is free software: you can redistribute it and/or
-# modify it under the terms of the GNU Lesser General Public
-# License as published by the Free Software Foundation, either
-# version 3 of the License, or (at your option) any later version.
-#
-# This library is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-# Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public
-# License along with this library.  If not, see <http://www.gnu.org/licenses/>.
