@@ -204,7 +204,19 @@ class PowerShellBase(Shell):
             executor.command(shell_command)
 
         # Forward exit call to parent PowerShell process
-        executor.command("exit $LastExitCode")
+        #
+        # Note that in powershell, $LASTEXITCODE is only set after running an
+        # executable - in other cases (such as when a command is not found),
+        # only the bool $? var is set.
+        #
+        executor.command(
+            "if(! $?) {\n"
+            "  if ($LASTEXITCODE) {\n"
+            "    exit $LASTEXITCODE\n"
+            "  }\n"
+            "  exit 1\n"
+            "}"
+        )
 
         code = executor.get_output()
         target_file = os.path.join(tmpdir,
@@ -270,14 +282,15 @@ class PowerShellBase(Shell):
 
     def setenv(self, key, value):
         value = self.escape_string(value)
-        self._addline('$Env:{0} = "{1}"'.format(key, value))
+        self._addline('Set-Item -Path "Env:{0}" -Value "{1}"'.format(key, value))
 
     def appendenv(self, key, value):
         value = self.escape_string(value)
         # Be careful about ambiguous case in pwsh on Linux where pathsep is :
         # so that the ${ENV:VAR} form has to be used to not collide.
         self._addline(
-            '$Env:{0} = "${{Env:{0}}}{1}{2}"'.format(key, os.path.pathsep, value)
+            'Set-Item -Path "Env:{0}" -Value ((Get-ChildItem "Env:{0}").Value + "{1}{2}")'.format(
+                key, os.path.pathsep, value)
         )
 
     def unsetenv(self, key):
